@@ -24,8 +24,9 @@ at the man output, we look one step before at the generated rst output
 from awscli.testutils import BaseAWSHelpOutputTest
 from awscli.testutils import FileCreator
 from awscli.testutils import mock
+from awscli.testutils import aws
+from awscli.compat import StringIO
 
-from awscli.compat import six
 from awscli.alias import AliasLoader
 
 
@@ -203,7 +204,7 @@ class TestRemoveDeprecatedCommands(BaseAWSHelpOutputTest):
         # command verify that we get a SystemExit exception
         # and that we get something in stderr that says that
         # we made an invalid choice (because the operation is removed).
-        stderr = six.StringIO()
+        stderr = StringIO()
         with mock.patch('sys.stderr', stderr):
             with self.assertRaises(SystemExit):
                 self.driver.main([service, command, 'help'])
@@ -482,3 +483,11 @@ class TestStreamingOutputHelp(BaseAWSHelpOutputTest):
         self.driver.main(['s3api', 'get-object', 'help'])
         self.assert_not_contains('outfile <value>')
         self.assert_contains('<outfile>')
+
+
+# Use this test class for "help" cases that require the default renderer
+# (i.e. renderer from get_render()) instead of a mocked version.
+class TestHelpOutputDefaultRenderer:
+    def test_line_lengths_do_not_break_create_launch_template_version_cmd(self):
+        result = aws('ec2 create-launch-template-version help')
+        assert 'exceeds the line-length-limit' not in result.stderr
